@@ -54,6 +54,8 @@ module FileHandlers
     param 'defaultMetaInfo', {}, 'The keys for this hash are the names of file handlers, the ' +
       'values hashes with meta data.'
 
+    param 'useHiddenFiles', false, 'Files starting with a dot can also used by the file handler plugins if set to true.'
+
     depends_on 'Core/Configuration'
 
     include Listener
@@ -283,7 +285,7 @@ module FileHandlers
 
     # Returns an array of files of the source directory matching +pattern+
     def files_for_pattern( pattern )
-      files = Dir.glob( File.join( param( 'srcDir', 'Core/Configuration' ), pattern ), File::FNM_CASEFOLD ).to_set
+      files = Dir.glob( File.join( param( 'srcDir', 'Core/Configuration' ), pattern ), (param('useHiddenFiles') ? File::FNM_DOTMATCH : 0) | File::FNM_CASEFOLD ).to_set
       files.delete( File.join( param( 'srcDir', 'Core/Configuration' ), '/' ) )
       files.collect!  do |f|
         f = f.sub( /([^.])\.{1,2}$/, '\1' ) # remove '.' and '..' from end of paths
