@@ -68,7 +68,7 @@ module FileHandlers
 
       # Overwritten to also handle matching of the page name and the local page name.
       def =~( path )
-        md = /^(#{@path}|#{@node_info[:local_pagename]}|#{@node_info[:pagename]})(?=#|$)/ =~ path
+        md = /^(#{Regexp.escape(@path)}|#{Regexp.escape(@node_info[:local_pagename])}|#{Regexp.escape(@node_info[:pagename])})(?=#|$)/ =~ path
         ( md ? $& : nil )
       end
 
@@ -131,7 +131,7 @@ module FileHandlers
         return nil
       end
 
-      data.meta_info.update( meta_info )
+      data.meta_info.update( meta_info.merge( data.meta_info ) )
       analysed_name = analyse_file_name( filename, data.meta_info['lang'] )
 
       data.meta_info['lang'] ||= analysed_name.lang
