@@ -36,13 +36,12 @@ module FileHandlers
 
     register_extension 'template'
 
-    default_meta_info( 'blocks' => [['content', 'html']] )
+    default_meta_info( 'useERB' => true, 'blocks' => [['content', 'html']] )
 
     def create_node( src_name, parent, meta_info )
       begin
-        page_meta_info = @plugin_manager['Core/FileHandler'].meta_info_for( @plugin_manager['File/PageHandler'] )
         data = WebPageData.new( File.read( src_name ), @plugin_manager['ContentConverter/Default'].registered_handlers,
-                                page_meta_info.merge( meta_info ) )
+                                meta_info )
       rescue WebPageDataInvalid => e
         log(:error) { "Invalid template file <#{src_name}>: #{e.message}" }
         return nil
