@@ -1,7 +1,7 @@
 #
 #--
 #
-# $Id: default.rb 369 2005-12-24 11:37:40Z thomas $
+# $Id: default.rb 531 2006-11-17 17:56:14Z thomas $
 #
 # webgen: template based static website generator
 # Copyright (C) 2004 Thomas Leitner
@@ -20,16 +20,18 @@
 #++
 #
 
-module HTMLValidators
+module HtmlValidators
 
-  class DefaultHTMLValidator < Webgen::Plugin
+  class DefaultHtmlValidator < Webgen::HandlerPlugin
 
-    summary "Base class for all HTML validators"
+    infos( :name => 'HtmlValidator/Default',
+           :author => Webgen::AUTHOR,
+           :summary => "Base class for all HTML validators"
+           )
 
-    define_handler 'validator'
-
-    # Should be overridden in subclass!
+    # Validates the file +filename+. Has to be overridden in subclasses!
     def validate_file( filename )
+      raise NotImplementedError
     end
 
   end
