@@ -65,7 +65,12 @@ module MenuStyles
       styles << param( 'selectedMenuitemClass' ) if node == src_node
 
       style = "class=\"#{styles.join(' ')}\"" if styles.length > 0
-      link = node.link_from( src_node )
+      link = node.link_from( src_node, :context => {
+                               :caller => self.class.plugin_name,
+                               :selected => (node == src_node),
+                               :directory => node.is_directory?,
+                               :inHierarchy => node.is_directory? && src_node.in_subtree_of?( node )
+                             } )
 
       return style, link
     end
