@@ -31,6 +31,11 @@ module MenuStyles
            :summary => "Builds a horizontal menu"
            )
 
+    param 'startLevel', 1, 'The level at which the menu starts. For example, if set to 2 the top most ' +
+      'menu items are not shown.'
+    param 'maxLevels', 3,  'Specifies the maximum number of levels that should be shown. ' +
+      'For example, if maxLevels = 1, then only one level is shown.'
+
     register_handler 'horizontal'
 
     def internal_build_menu( src_node, menu_tree )
@@ -51,7 +56,9 @@ module MenuStyles
     #######
 
     def submenu( src_node, menu_node, level )
-      if menu_node.nil? || menu_node.level > src_node.level \
+      if menu_node.nil? \
+        || level > param( 'maxLevels' ) + param( 'startLevel' ) - 1 \
+        || src_node.level < param( 'startLevel' ) \
         || !src_node.in_subtree_of?( menu_node.node_info[:node] )
         return ''
       end
@@ -61,12 +68,16 @@ module MenuStyles
       menu_node.each do |child|
         submenu << (child.has_children? ? submenu( src_node, child, level + 1 ) : '')
         style, link = menu_item_details( src_node, child.node_info[:node] )
-        out << "<li #{style}>#{link}</li>"
+        out << "<li#{style.to_s.empty? ? '' : ' ' + style}>#{link}</li>"
       end
       out << "</ul>"
       out << submenu
 
-      return out
+      if level < param( 'startLevel' )
+        '' + submenu
+      else
+        out
+      end
     end
 
   end
