@@ -60,7 +60,7 @@ module Tags
       node = node.parent if omitIndexFile
 
       until node.nil?
-        out.push( node.link_from( chain.last ) )
+        out.push( node.link_from( chain.last, :context => { :caller => self.class.plugin_name } ) )
         node = node.parent
       end
 
