@@ -1,7 +1,7 @@
 #
 #--
 #
-# $Id: date.rb 369 2005-12-24 11:37:40Z thomas $
+# $Id: date.rb 562 2006-12-28 08:00:37Z thomas $
 #
 # webgen: template based static website generator
 # Copyright (C) 2004 Thomas Leitner
@@ -20,7 +20,7 @@
 #++
 #
 
-require 'webgen/plugins/tags/tags'
+load_plugin 'webgen/plugins/tags/tag_processor'
 
 module Tags
 
@@ -28,13 +28,17 @@ module Tags
   # can use everything Time#strftime offers.
   class DateTag < DefaultTag
 
-    summary "Prints out the date"
-    add_param 'format', '%A, %B %d %H:%M:%S %Z %Y', 'The format of the date (same options as Time#strftime).'
+    infos( :name => 'Tag/Date',
+           :author => Webgen::AUTHOR,
+           :summary => "Prints out the current date/time in a customizable format"
+           )
 
-    tag 'date'
+    param 'format', '%A, %B %d %H:%M:%S %Z %Y', 'The format of the date (same options as Ruby\'s Time#strftime).'
 
-    def process_tag( tag, node, refNode )
-      Time.now.strftime( get_param( 'format' ) )
+    register_tag 'date'
+
+    def process_tag( tag, chain )
+      Time.now.strftime( param( 'format' ) )
     end
 
   end
