@@ -45,7 +45,7 @@ module Tags
       langs = langs.
         delete_if {|child| (cur_node['lang'] == child['lang'] && !param( 'showOwnLang' )) }.
         sort {|a, b| a['lang'] <=> b['lang']}.
-        collect {|n| n.link_from( cur_node, :resolve_lang_node => false, :link_text => n['lang'] )}.
+        collect {|n| n.link_from( cur_node, :resolve_lang_node => false, :link_text => n['lang'], :context => { :caller => self.class.plugin_name } )}.
         join( param( 'separator' ) )
       ( param( 'showSingleLang' ) || nr_langs > 1 ? langs : "" )
     end
