@@ -64,7 +64,7 @@ module Tags
            (!node['indexFile'].nil? && node['indexFile'].node_info[:pagename] == child.node_info[:pagename] && !node.parent.nil?))
 
         subout = output_node( child, src_node )
-        link = child.link_from( src_node ) if !child.is_directory? || subout != ''
+        link = child.link_from( src_node, :context => { :caller => self.class.plugin_name } ) if !child.is_directory? || subout != ''
 
         temp += "<#{param( 'itemTag' )}>#{link}" if !child.is_directory? || subout != ''
         temp += subout if child.is_directory?
