@@ -11,7 +11,7 @@ class ConfigTest < Webgen::TestCase
 
   def test_data_dir
     assert_nothing_raised do
-      assert_not_equal( '', Webgen.data_dir )
+      assert_equal( File.expand_path( File.join( File.dirname( __FILE__ ), '..', '..', 'data', 'webgen' ) ), Webgen.data_dir )
     end
   end
 
